-- DirXML ASN1 Schema Definitions
-- Novell Inc.
-- 122 East 1700 South
-- Provo, UT 84606-6194

-- VeRsIoN=Tao 1.0
-- CoPyRiGhT=(c) Copyright 1997, 2000, Novell, Inc.  All rights reserved

-- Object ID Syntax
------------------------------------------
------------------------------------------
-- ASN1 Object ID's Defined as Follows:
--     joint-iso-ccitt(2) country(16) us(840) organization(1)
--     Novell(113719) applications(1) NDS(1)  NDSAttributeType(4)
--                                            NDSAttributeSyntax(5)
--                                            NDSObjectClass(6)
--              revision number(1) sequence number(1)
------------------------------------------
-- One Additional Digit was added before the attribute or object
-- identifier to identify the release number.  This number reflects
-- the release number in which the object or attribute was added to the
-- definition.  The first release would have the ID 1 and count up from
-- there.
-- An example of the attribute of the first revision with sequence 1 would be:
-- 2 16 840 1 113719 1 1 4 1 1.
-- The attribute of the third revision with sequence 4 would be:
-- 2 16 840 1 113719 1 1 4 3 4.
------------------------------------------

NDSSchemaExtensions DEFINITIONS ::=
BEGIN

--
-- The XML Data holds XML encoded data
--
"XmlData" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR},
	SyntaxID		SYN_STREAM,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 3}
}

--
-- The Association attribute serves as a junction point to other applications.
--
-- Issue: Should this attribute only exist on the Tao server that is providing
-- the replication to the "foreign" app? The example that I can think of where
-- we would not want this to be the case is if we have more than one Tao server
-- providing replication services to the same foreign app and it may be possible
-- for the same object to be replicated through any of the Tao servers providing
-- the junction point.
--
-- The association is syntax path where:
-- 	volumeDN = DN of the VR Driver
--	namespacetype = state of the association
--	path = Foreign Key
--
-- THE DirXML-Associations attribute is now part of the operational schema. 

--
-- The ShimAuthID provides the ID that will be passed to the App Shim to
-- allow for shim authentication to the foreign app.
--
"DirXML-ShimAuthID" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR, DS_PER_REPLICA},
	SyntaxID		SYN_CI_STRING,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 5}
}

--
-- The ShimAuthPassword provides the password that will be passed to the App 
-- Shim to allow for shim authentication to the foreign app.
--
"DirXML-ShimAuthPassword" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR, DS_PER_REPLICA},
	SyntaxID		SYN_OCTET_STRING,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 6}
}

--
-- The ShimAuthServer provides information about the server that should be
-- used by the App Shim to authenticate.
--
"DirXML-ShimAuthServer" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR, DS_PER_REPLICA},
	SyntaxID		SYN_CI_STRING,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 7}
}

--
-- The ShimAuthConfig provides any further information that should be
-- used by the App Shim for initial configuration.
--
"DirXML-ShimConfigInfo" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR, DS_PER_REPLICA},
	SyntaxID		SYN_STREAM,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 8}
}

--
-- The Native Module specifies the name of the DLL/NLM/Shared Library that 
-- should be loaded to serve as the Shim for this driver. It is expected that
-- this library will provide a number of well defined entry points that are
-- the Shim Subscriber API
--
"DirXML-NativeModule" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR},
	SyntaxID		SYN_CI_STRING,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 9}
}

--
-- The Java Module specifies the name of the java class that should be loaded
-- to serve as the Shim for this driver. This class must provide an 
-- implementation of the com.novell.nds.vrdriver.SubscriberShim interface.
--
"DirXML-JavaModule" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR},
	SyntaxID		SYN_CI_STRING,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 10}
}

--
-- Contains the filter specification of what information will be allowed to
-- pass to/from the foreign app and NDS
--
"DirXML-DriverFilter" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR},
	SyntaxID		SYN_STREAM,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 11}
}

--
-- This attribute references the container that holds the driver definitions
-- that are to be run on any given server. The Driver Set can be used by more
-- than one Tao Server.  This attribute is set in a server's pseudo-server
-- object.
--
"DirXML-DriverSetDN" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR},
	SyntaxID		SYN_DIST_NAME,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 12}
}

--
-- This contains one of three values that indicate if the driver 
-- 1) should be started automatically at NDS boot time (by the VRIM), 
-- 2) started manually by some user interface, or 
-- 3) is disabled and cannot be started until value is set to AUTO or MANUAL.
--
"DirXML-DriverStartOption" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SCHEDULE_SYNC_NEVER, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR, DS_READ_ONLY_ATTR, DS_PUBLIC_READ, DS_PER_REPLICA},
	SyntaxID		SYN_INTEGER,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 13}
}

--
-- This value indicates the current status of the driver on a specific system
-- OR the modification state of a Driver Filter on a Subscriber or Publisher
-- object.  
--
-- For a Driver State:
-- Currently supported states are STOPPED, STARTING, RUNNING, SHUTDOWN_PENDING.  
-- The STARTING and SHUTDOWN_PENDING states may be set via an administrative 
-- utility using the DDCSetIntegrationDriverState API functionality.
-- DDCGetIntegrationDriverState is available to allow a utility to retrieve 
-- the status of the specific driver instance.
--
-- For a Pub/Sub filter state:
-- Currently supported states are CURRENT and MODIFIED.
--
"DirXML-State" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SCHEDULE_SYNC_NEVER, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR, DS_READ_ONLY_ATTR, DS_PUBLIC_READ, DS_PER_REPLICA},
	SyntaxID		SYN_INTEGER,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 14}
}

--
-- The server list attribute holds the DNs of the servers that make use of a
-- given driver set
--
"DirXML-ServerList" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_NONREMOVABLE_ATTR},
	SyntaxID		SYN_DIST_NAME,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 15}
}

-- 
-- Serves as the "sychronized up to" vector for a given driver
--
"DirXML-Timestamp" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SCHEDULE_SYNC_NEVER, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR, DS_READ_ONLY_ATTR, DS_PUBLIC_READ, DS_PER_REPLICA},
	SyntaxID		SYN_TIMESTAMP,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 16}
}

-- 
-- The Input Transform represents the XSLT processing that will be 
-- performed during a an attempt to auto-correlate a given subscription/publication
-- event. It is used to transform App native format into XDS.
--
-- This is a DN attribute that references an object of type XSLT Style Sheet
--
"DirXML-InputTransform" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR},
	SyntaxID		SYN_DIST_NAME,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 17}
}

-- 
-- The Output Transform represents the XSLT processing that will be 
-- performed during a an attempt to auto-correlate a given subscription/publication
-- event. It is used to transform XDS into App native format.
--
-- This is a DN attribute that references an object of type XSLT Style Sheet
--
"DirXML-OutputTransform" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR},
	SyntaxID		SYN_DIST_NAME,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 18}
}

-- 
-- The Mapping Rule represents the XML rule that will be used to map
-- class and attribute names between the NDS and Application namespaces
--
-- This is a DN attribute that references an object of type DirXML-Rule
--
"DirXML-MappingRule" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR},
	SyntaxID		SYN_DIST_NAME,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 19}
}

-- 
-- The Placement Rule represents the XML rule that will be used to
-- place newly created objects into a hierchical namespace.
--
-- This is a DN attribute that references an object of type DirXML-Rule
--
"DirXML-PlacementRule" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR},
	SyntaxID		SYN_DIST_NAME,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 20}
}

-- 
-- The Matching Rule represents the XML rule that will be used to
-- match up objects between the NDS and an Application
--
-- This is a DN attribute that references an object of type DirXML-Rule
--
"DirXML-MatchingRule" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR},
	SyntaxID		SYN_DIST_NAME,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 21}
}

-- 
-- The Create Rule represents the XML rule that will be used to
-- decide whether or not to go ahead and create a new object
--
-- This is a DN attribute that references an object of type DirXML-Rule
--
"DirXML-CreateRule" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR},
	SyntaxID		SYN_DIST_NAME,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 22}
}

-- 
-- The Event Transformation Rule represents the XML rule that will be used to
-- transform events from one type to another
--
-- This is a DN attribute that references an object of type DirXML-Rule
--
"DirXML-EventTransformationRule" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR},
	SyntaxID		SYN_DIST_NAME,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 23}
}

-- 
-- The Driver Cache Limit holds the maximum size that the driver cache file can grow to
-- before causing a cache overflow condition 
--
"DirXML-DriverCacheLimit" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SCHEDULE_SYNC_NEVER, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR, DS_READ_ONLY_ATTR, DS_PUBLIC_READ, DS_PER_REPLICA},
	SyntaxID		SYN_INTEGER,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 24}
}

-- 
-- The Driver Trace Level is the maximimum level of DirXML trace message
-- to output for drivers in the Driver Set
--
"DirXML-DriverTraceLevel" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR},
	SyntaxID		SYN_INTEGER,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 25}
}

-- 
-- The Driver Trace Level is the maximimum level of XSL trace messages
-- to output for the XSL processor
--
"DirXML-XSLTraceLevel" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR},
	SyntaxID		SYN_INTEGER,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 26}
}

-- 
-- The Java Debug Port to specify the use of a debugging port on the
-- Java Virtual Machine, 0 = none, -1 = autoselect
--
"DirXML-JavaDebugPort" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR},
	SyntaxID		SYN_INTEGER,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 27}
}

-- 
-- The Java Trace File is where all Java System.out and System.err output can be logged
--
"DirXML-JavaTraceFile" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR},
	SyntaxID		SYN_CI_STRING,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 28}
}

-- 
-- The Application Schema is where the XML that describes the Application Schema is stored
--
"DirXML-ApplicationSchema" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR},
	SyntaxID		SYN_STREAM,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 29}
}

-- 
-- The DriverStorage is where a driver can store any information it may need
-- between invocations. The information is stored as XML.
--
"DirXML-DriverStorage" ATTRIBUTE ::=
{
	Operation		ADD,
	Flags			{DS_SYNC_IMMEDIATE, DS_NONREMOVABLE_ATTR, DS_SINGLE_VALUED_ATTR, DS_PER_REPLICA},
	SyntaxID		SYN_STREAM,
	ASN1ObjID		{2 16 840 1 113719 1 14 4 1 30}
}

--
-- With the Tao release of NDS, all objects in the tree will be candidates for
-- sychronization with foreign applications.
--
"Top" OBJECT-CLASS ::=
{
	Operation		MODIFY,
	MayContain		{"DirXML-Associations"}
}

--
-- A driver set holds all drivers that are applicable for a give server.
-- The driver set should be defined as a seperate partition with a replica
-- placed on all Tao servers that will use this driver set.
--
"DirXML-DriverSet" OBJECT-CLASS ::=
{
	Operation		ADD,
	Flags			{DS_CONTAINER_CLASS,DS_EFFECTIVE_CLASS,DS_NONREMOVABLE_CLASS},
	SubClassOf		{"Top"},
	ContainedBy		{"Country", "Locality", "domain", "Organization", "Organizational Unit"},
	NamedBy			{"CN"},
	MustContain		{"CN"},
	MayContain		{"DirXML-ServerList"},
	MayContain		{"DirXML-DriverTraceLevel"},
	MayContain		{"DirXML-XSLTraceLevel"},
	MayContain		{"DirXML-JavaDebugPort"},
	MayContain		{"DirXML-JavaTraceFile"},
	ASN1ObjID		{2 16 840 1 113719 1 14 6 1 1}
}

-- 
-- The driver is the focal point of configuration of replication from NDS to
-- foreign applications.
--
"DirXML-Driver" OBJECT-CLASS ::=
{
	Operation		ADD,
	Flags			{DS_CONTAINER_CLASS,DS_EFFECTIVE_CLASS,DS_NONREMOVABLE_CLASS},
	SubClassOf		{"Top"},
	ContainedBy		{"DirXML-DriverSet"},
	NamedBy			{"CN"},
	MustContain		{"CN"},
	MayContain		{"DirXML-DriverCacheLimit"},
	MayContain		{"DirXML-DriverStartOption"},
	MayContain		{"DirXML-ShimConfigInfo"},
	MayContain		{"DirXML-ShimAuthID"},
	MayContain		{"DirXML-ShimAuthPassword"},
	MayContain		{"DirXML-ShimAuthServer"},
	MayContain		{"DirXML-State"},
	MayContain		{"DirXML-NativeModule"},
	MayContain		{"DirXML-JavaModule"},
	MayContain		{"DirXML-InputTransform"},
	MayContain		{"DirXML-OutputTransform"},
	MayContain		{"DirXML-MappingRule"},
	MayContain		{"DirXML-ApplicationSchema"},
	MayContain		{"DirXML-DriverStorage"},
	ASN1ObjID		{2 16 840 1 113719 1 14 6 1 2}
}

--
-- Attributes that have been relocated from Tao Beta 3 to Beta 4
--
"DirXML-Driver" OBJECT-CLASS ::=
{
	Operation		MODIFY,
	MayContain		{"Private Key", "Public Key", "Security Equals"}
}

--
-- The relationship between a Driver object and the corresponding publisher
-- and/or subscriber objects is strictly by containment. There will be zero
-- or one subscriber/publisher objects for any given driver object. This
-- will be enforced by the Console One snap-in only.
--

-- 
-- The publisher contains all information necessary to allow a foreign
-- application to publish information to the Directory.
--
"DirXML-Publisher" OBJECT-CLASS ::=
{
	Operation		ADD,
	Flags			{DS_CONTAINER_CLASS,DS_EFFECTIVE_CLASS,DS_NONREMOVABLE_CLASS},
	SubClassOf		{"Top"},
	ContainedBy		{"DirXML-Driver"},
	NamedBy			{"CN"},
	MustContain		{"CN"},
	MayContain		{"Private Key"},
	MayContain		{"Public Key"},
	MayContain		{"DirXML-DriverFilter"},
	MayContain		{"DirXML-PlacementRule"},
	MayContain		{"DirXML-MatchingRule"},
	MayContain		{"DirXML-CreateRule"},
	MayContain		{"DirXML-EventTransformationRule"},
	ASN1ObjID		{2 16 840 1 113719 1 14 6 1 3}
}

--
-- The subscriber contains all the information necessary to allow a foreign
-- application to subscribe to changes within the Directory.
--
"DirXML-Subscriber" OBJECT-CLASS ::=
{
	Operation		ADD,
	Flags			{DS_CONTAINER_CLASS,DS_EFFECTIVE_CLASS,DS_NONREMOVABLE_CLASS},
	SubClassOf		{"Top"},
	ContainedBy		{"DirXML-Driver"},
	NamedBy			{"CN"},
	MustContain		{"CN"},
	MayContain		{"DirXML-DriverFilter"},
	MayContain		{"DirXML-Timestamp"},
	MayContain		{"DirXML-PlacementRule"},
	MayContain		{"DirXML-MatchingRule"},
	MayContain		{"DirXML-CreateRule"},
	MayContain		{"DirXML-EventTransformationRule"},
	ASN1ObjID		{2 16 840 1 113719 1 14 6 1 4}
}

--
-- A general style sheet object is being added to hold XML styling information
--
"StyleSheet" OBJECT-CLASS ::=
{
	Operation		ADD,
	Flags			{DS_EFFECTIVE_CLASS,DS_NONREMOVABLE_CLASS},
	SubClassOf		{"Top"},
	ContainedBy		{"Country", "Locality", "domain", "Organization", "Organizational Unit"},
	NamedBy			{"CN"},
	MustContain		{"CN"},
	MayContain		{"XmlData"},
	ASN1ObjID		{2 16 840 1 113719 1 14 6 1 5}
}

-- 
-- DirXML Style sheets may also be contained by Driver Sets, Drivers, Publishers, 
-- and Subscribers
--
"DirXML-StyleSheet" OBJECT-CLASS ::=
{
	Operation		ADD,
	Flags			{DS_EFFECTIVE_CLASS,DS_NONREMOVABLE_CLASS},
	SubClassOf		{"StyleSheet"},
	ContainedBy		{"DirXML-Publisher", "DirXML-Subscriber", "DirXML-Driver"},
	ASN1ObjID		{2 16 840 1 113719 1 14 6 1 6}
}

--
-- A DirXML rule object is being added to hold rule information for the transformation 
-- of data to driver formats
--
"DirXML-Rule" OBJECT-CLASS ::=
{
	Operation		ADD,
	Flags			{DS_EFFECTIVE_CLASS,DS_NONREMOVABLE_CLASS},
	SubClassOf		{"Top"},
	ContainedBy		{"DirXML-Publisher", "DirXML-Subscriber", "DirXML-Driver"},
	NamedBy			{"CN"},
	MustContain		{"CN"},
	MayContain		{"XmlData"},
	ASN1ObjID		{2 16 840 1 113719 1 14 6 1 7}
}

END

